\name{twoislands}
\alias{twoislands}
%- Also NEED an '\alias' for EACH other topic documented here.
\title{Simulation of multilocus genotypes from a spatial variant of 
Wright's two-islands model}
\description{Simulates spatial coordinates and multilocus genotypes from a spatial
variant of the two-islands model.}

\usage{
twoislands(path, npop1, npop2,nloci, Theta = 1, M = 1, xpop1 = 4, ypop = 4, d=2,
s1=1, s2=1, plot=TRUE, print=FALSE, write=FALSE)
}
%- maybe also 'usage' for other objects documented here.
\arguments{
  \item{path}{ Character, path to an external file where the results giving the population membership for each individual could be stored  and/or variables involved in the simulation should be written}
  \item{npop1}{ Number of individuals in population 1}
  \item{npop2}{ Number of individuals in population 2}
  \item{nloci}{ Number of loci}
  \item{Theta}{ Effective mutation rate Theta = 4 mu Ne}
  \item{M}{ Effective migration rate M = 4 m Ne}
  \item{xpop1}{ Mean of x-coordinates in population 1}
  \item{ypop}{ Mean of y-coordinates in populations 1 and 2}
  \item{d}{ Distance between barycenters of populations }
  \item{s1}{ Standard deviation of x-coordinates in population 1 }
  \item{s2}{ Standard deviation of x-coordinates in population2  }
  \item{plot}{Logical: if \code{TRUE}, plots a colored representation of cluster membership}
  \item{print}{Logical: if \code{TRUE}, the map is also printed }
  \item{write}{Logical: if \code{TRUE}, coordinates, genotypes, cluster membership, number of alleles, and Fst's involved in the simulation are also written in plain ascii files}
}

\value{

\item{coordinates}{ Spatial coordinates og individuals (matrix)}
\item{Fst}{ Theoretical value of the Fst}
\item{meanfste}{ Weir and Cockerham's estimate of the Fst}
\item{v}{ Ratio of intra group variance to inter group variance}
\item{genotypes}{ Genotypes (matrix)}
\item{allele.numbers}{ Number of distinct alleles at each locus}
\item{popmbrship}{ Cluster membership}
}

\details{ The genotypes are simulated from the infinite allele model of mutation along a structured coalescent tree with constant gene flows (two-islands model).
The spatial coordinates are simulated as a mixture of two-dimensional Gaussian distributions.}

\author{ 
Sophie Ancelet 
Olivier Francois
}

\seealso{ \code{\link{as.geneclustdata}}, \code{\link{simpatch}}}
\keyword{}


\examples{

# library(Geneclust)

# Simulation of a dataset according to the 2 islands model.
# The data consist of 2 populations. Each population contains 50 individuals. 
# 10 loci are genotyped. The centers are separated by a distance d = 2.

\dontrun{
#  define a folder for simulation outputs
#To define a place for simulation outputs
system("mkdir ./tmpData/")
path <- "./tmpIslands/"

obj <-  twoislands( path=path,
                    npop1=50,
                    npop2=50,
                    nloci=10,
                    Theta=1,
                    M=1,
                    xpop1=4,
                    ypop=4,
                    d=2,
                    s1=1,
                    s2=1,
                    plot=TRUE,
                    print=FALSE,
                    write=FALSE)

## go to file path to read simulation outputs

data <- as.geneclustdata(x = obj$coordinates[,1],
                         y = obj$coordinates[,2],
                         genotype = obj$genotypes)

summarygeneclustdata(data) 

#Average empirical Fst
obj$meanfste

#Weir and Cockerham's estimator of Fst
Fst(obj$genotypes,obj$allele.numbers,obj$popmbrship)$Pairwise.Fst



}}

